summaryrefslogtreecommitdiff
path: root/render/font.h
diff options
context:
space:
mode:
Diffstat (limited to 'render/font.h')
-rw-r--r--render/font.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/render/font.h b/render/font.h
index fba368a97..52f5a62c2 100644
--- a/render/font.h
+++ b/render/font.h
@@ -32,10 +32,13 @@ struct plot_font_style;
/**
* Populate a font style using data from a computed CSS style
*
* \param css Computed style to consider
* \param fstyle Font style to populate
*/
-void font_plot_style_from_css(const css_computed_style *css,
- struct plot_font_style *fstyle);
+void font_plot_style_from_css(
+ const nscss_len_ctx *len_ctx,
+ const css_computed_style *css,
+ struct plot_font_style *fstyle);
#endif
@@ -32,10 +32,13 @@ struct plot_font_style;
* Populate a font style using data from a computed CSS style
*
- * \param css Computed style to consider
- * \param fstyle Font style to populate
+ * \param len_ctx Length conversion context
+ * \param css Computed style to consider
+ * \param fstyle Font style to populate
*/